DataErrorKind

Enum DataErrorKind 

#[non_exhaustive]
pub enum DataErrorKind { MissingDataKey, MissingLocale, NeedsLocale, ExtraneousLocale, FilteredResource, MismatchedType(&'static str), MissingPayload, InvalidState, KeyLocaleSyntax, Custom, UnavailableBufferFormat(BufferFormat), }
A list specifying general categories of data provider error.

Errors may be caused either by a malformed request or by the data provider not being able to fulfill a well-formed request.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


MissingDataKey

No data for the provided resource key.



MissingLocale

There is data for the key, but not for this particular locale.



NeedsLocale

The request should include a locale.



ExtraneousLocale

The request should not contain a locale.



FilteredResource

The resource was blocked by a filter. The resource may or may not be available.



MismatchedType(&'static str)

The generic type parameter does not match the TypeId. The expected type name is stored as context when this error is returned.



MissingPayload

The payload is missing. This is usually caused by a previous error.



InvalidState

A data provider object was given to an operation in an invalid state.



KeyLocaleSyntax

The syntax of the DataKey or DataLocale was invalid.



Custom

An unspecified error occurred, such as a Serde error.

Check debug logs for potentially more information.



UnavailableBufferFormat(BufferFormat)

An error indicating that the desired buffer format is not available. This usually means that a required Cargo feature was not enabled

Implementations

Source

impl DataErrorKind

pub const fn into_error(self) -> DataError

Converts this DataErrorKind into a DataError.

If possible, you should attach context using a with_ function.

pub const fn with_key(self, key: DataKey) -> DataError

Creates a DataError with a resource key context.

pub const fn with_str_context(self, context: &'static str) -> DataError

Creates a DataError with a string context.

pub fn with_type_context<T>(self) -> DataError

Creates a DataError with a type name context.

pub fn with_req(self, key: DataKey, req: DataRequest<'_>) -> DataError

Creates a DataError with a request context.